HttpClient

Struct HttpClient 

pub struct HttpClient { /* private fields */ }
HTTP client for Consul API

Implementations

Source

impl HttpClient

pub fn new(config: Config) -> Result<Self>

Create a new HTTP client with the given configuration

pub fn config(&self) -> &Config

Get the configuration

pub fn url(&self, path: &str) -> String

Build the full URL for an API path

pub fn get(&self, path: &str) -> RequestBuilder

Create a GET request builder

pub fn put(&self, path: &str) -> RequestBuilder

Create a PUT request builder

pub fn post(&self, path: &str) -> RequestBuilder

Create a POST request builder

pub fn delete(&self, path: &str) -> RequestBuilder

Create a DELETE request builder

pub fn apply_query_options( &self, builder: RequestBuilder, opts: &QueryOptions, ) -> RequestBuilder

Apply query options to a request

pub fn apply_write_options( &self, builder: RequestBuilder, opts: &WriteOptions, ) -> RequestBuilder

Apply write options to a request

pub async fn execute(&self, builder: RequestBuilder) -> Result<Response>

Execute a request and return the response

pub async fn execute_json<T: DeserializeOwned>( &self, builder: RequestBuilder, ) -> Result<T>

Execute a request and parse the response as JSON

pub async fn query<T: DeserializeOwned>( &self, builder: RequestBuilder, ) -> Result<(T, QueryMeta)>

Execute a query request and return response with metadata

pub async fn write<T: DeserializeOwned>( &self, builder: RequestBuilder, ) -> Result<(T, WriteMeta)>

Execute a write request and return response with metadata

pub async fn write_bool( &self, builder: RequestBuilder, ) -> Result<(bool, WriteMeta)>

Execute a write request that returns a boolean

pub async fn write_empty(&self, builder: RequestBuilder) -> Result<WriteMeta>

Execute a write request that returns no content

pub async fn ping(&self) -> Result<()>

Check if server is reachable