QueryMeta

Struct QueryMeta 

pub struct QueryMeta {
    pub last_index: u64,
    pub last_contact: Duration,
    pub known_leader: bool,
    pub request_time: Duration,
    pub address_translation_enabled: bool,
    pub cache_hit: bool,
    pub cache_age: Option<Duration>,
}
Metadata returned from query operations

Fields

last_index: u64

LastIndex can be used for blocking queries

last_contact: Duration

LastContact is the time of last contact from leader

known_leader: bool

KnownLeader indicates if there is a known leader

request_time: Duration

RequestTime is how long the request took

address_translation_enabled: bool

AddressTranslationEnabled indicates if address translation is enabled

cache_hit: bool

CacheHit indicates if the response was a cache hit

cache_age: Option<Duration>

CacheAge is how old the cached response is