pub struct QueryMeta {
pub last_index: u64,
pub last_contact: Duration,
pub known_leader: bool,
pub request_time: Duration,
pub address_translation_enabled: bool,
pub cache_hit: bool,
pub cache_age: Option<Duration>,
}Expand description
Metadata returned from query operations
Fields
last_index: u64LastIndex can be used for blocking queries
last_contact: DurationLastContact is the time of last contact from leader
known_leader: boolKnownLeader indicates if there is a known leader
request_time: DurationRequestTime is how long the request took
address_translation_enabled: boolAddressTranslationEnabled indicates if address translation is enabled
cache_hit: boolCacheHit indicates if the response was a cache hit
cache_age: Option<Duration>CacheAge is how old the cached response is